==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/UniqueKeyPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.UniqueKeyPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
 * @property uniqueKeys List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
 */
public data class UniqueKeyPolicyArgs(
    public val uniqueKeys: Output<List<UniqueKeyArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.UniqueKeyPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.UniqueKeyPolicyArgs =
        com.pulumi.azurenative.documentdb.inputs.UniqueKeyPolicyArgs.builder()
            .uniqueKeys(
                uniqueKeys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [UniqueKeyPolicyArgs].
 */
@PulumiTagMarker
public class UniqueKeyPolicyArgsBuilder internal constructor() {
    private var uniqueKeys: Output<List<UniqueKeyArgs>>? = null

    /**
     * @param value List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("bdlmnxiaakeavjtv")
    public suspend fun uniqueKeys(`value`: Output<List<UniqueKeyArgs>>) {
        this.uniqueKeys = value
    }

    @JvmName("vdsabmrcaxyeuibt")
    public suspend fun uniqueKeys(vararg values: Output<UniqueKeyArgs>) {
        this.uniqueKeys = Output.all(values.asList())
    }

    /**
     * @param values List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("qsxsxbmfqcgaxmgg")
    public suspend fun uniqueKeys(values: List<Output<UniqueKeyArgs>>) {
        this.uniqueKeys = Output.all(values)
    }

    /**
     * @param value List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("ksruqlkqrrooxagr")
    public suspend fun uniqueKeys(`value`: List<UniqueKeyArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uniqueKeys = mapped
    }

    /**
     * @param argument List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("llpxytbdjwjkyprh")
    public suspend fun uniqueKeys(argument: List<suspend UniqueKeyArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { UniqueKeyArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.uniqueKeys = mapped
    }

    /**
     * @param argument List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("aqgryqgmsjcmojhx")
    public suspend fun uniqueKeys(vararg argument: suspend UniqueKeyArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { UniqueKeyArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.uniqueKeys = mapped
    }

    /**
     * @param argument List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("cmavqqwlhfnlcqfq")
    public suspend fun uniqueKeys(argument: suspend UniqueKeyArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(UniqueKeyArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.uniqueKeys = mapped
    }

    /**
     * @param values List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("fbowcwtasmbprves")
    public suspend fun uniqueKeys(vararg values: UniqueKeyArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.uniqueKeys = mapped
    }

    internal fun build(): UniqueKeyPolicyArgs = UniqueKeyPolicyArgs(
        uniqueKeys = uniqueKeys,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/UniqueKeyPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.UniqueKeyPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
 * @property uniqueKeys List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
 */
public data class UniqueKeyPolicyArgs(
    public val uniqueKeys: Output<List<UniqueKeyArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.UniqueKeyPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.UniqueKeyPolicyArgs =
        com.pulumi.azurenative.documentdb.inputs.UniqueKeyPolicyArgs.builder()
            .uniqueKeys(
                uniqueKeys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [UniqueKeyPolicyArgs].
 */
@PulumiTagMarker
public class UniqueKeyPolicyArgsBuilder internal constructor() {
    private var uniqueKeys: Output<List<UniqueKeyArgs>>? = null

    /**
     * @param value List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("mpsrgefvraxqerxq")
    public suspend fun uniqueKeys(`value`: Output<List<UniqueKeyArgs>>) {
        this.uniqueKeys = value
    }

    @JvmName("vdhspntbywsuetvl")
    public suspend fun uniqueKeys(vararg values: Output<UniqueKeyArgs>) {
        this.uniqueKeys = Output.all(values.asList())
    }

    /**
     * @param values List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("lefwbqhxmjhrvspl")
    public suspend fun uniqueKeys(values: List<Output<UniqueKeyArgs>>) {
        this.uniqueKeys = Output.all(values)
    }

    /**
     * @param value List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("jrdykmyqrolrhlwn")
    public suspend fun uniqueKeys(`value`: List<UniqueKeyArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uniqueKeys = mapped
    }

    /**
     * @param argument List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("qkidxqobibgqucml")
    public suspend fun uniqueKeys(argument: List<suspend UniqueKeyArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { UniqueKeyArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.uniqueKeys = mapped
    }

    /**
     * @param argument List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("ccryhdfcukbgqekv")
    public suspend fun uniqueKeys(vararg argument: suspend UniqueKeyArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { UniqueKeyArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.uniqueKeys = mapped
    }

    /**
     * @param argument List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("pxgicvvgglejafbm")
    public suspend fun uniqueKeys(argument: suspend UniqueKeyArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(UniqueKeyArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.uniqueKeys = mapped
    }

    /**
     * @param values List of unique keys on that enforces uniqueness constraint on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("aiseoamkjqxnosqi")
    public suspend fun uniqueKeys(vararg values: UniqueKeyArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.uniqueKeys = mapped
    }

    internal fun build(): UniqueKeyPolicyArgs = UniqueKeyPolicyArgs(
        uniqueKeys = uniqueKeys,
    )
}
